@@ -2,7 +2,7 @@
  source: https://gist.github.com/1311010
  Get django-sekizai, django-compessor (and django-cms) playing nicely together
  re: https://github.com/ojii/django-sekizai/issues/4
- using: https://github.com/jezdez/django_compressor.git
+ using: https://github.com/django-compressor/django-compressor.git
  and: https://github.com/ojii/django-sekizai.git@0.6 or later
 """
 from compressor.templatetags.compress import CompressorNode
